import 'package:flutter/material.dart';
import 'package:hometec_ui/components/progress_bar/loading_progress_bar.dart';
import 'package:hometec_ui/components/state_list/model/state_list_model.dart';
import 'package:hometec_ui/resources/colors/color.dart';
import 'package:hometec_ui/resources/fonts/font.dart';

class StateList extends StatefulWidget {

  final Widget child;
  final Stream<StateListEnum> state;
  final String emptyMessage;
  final String errorMessage;

  const StateList({Key key, this.child, this.state, this.emptyMessage, this.errorMessage}) : super(key: key);

  @override
  _StateListState createState() => _StateListState(child, state, emptyMessage, errorMessage);
}

class _StateListState extends State<StateList> {
  final Widget child;
  final Stream<StateListEnum> state;
  final String emptyMessage;
  final String errorMessage;

  _StateListState(this.child, this.state, this.emptyMessage, this.errorMessage);

  @override
  Widget build(BuildContext context) {
    return StreamBuilder(
      stream: state,
      builder: (context, snapshot){
        if(snapshot.hasData)
          switch (snapshot.data) {
            case StateListEnum.success:
              return Container(
                child: child,
              );
            case StateListEnum.empty:
              return Padding(
                padding: EdgeInsets.all(24),
                child: Center(
                  child: Text(emptyMessage, textAlign: TextAlign.center, style: Font.bodyRegular.style(color: ECColor.textColor),),
                ),
              );
            case StateListEnum.error:
              return Padding(
                padding: EdgeInsets.all(24),
                child: Center(
                  child: Text(errorMessage, textAlign: TextAlign.center, style: Font.bodyRegular.style(color: ECColor.textColor),),
                ),
              );
            default:
              return Center(
                child: LoadingProgressBar(),
              );
          }
        else
          return Center(
                child: LoadingProgressBar(),
          );
      }
    );
  }
}